@@ -5,7 +5,7 @@ from PySide.QtCore import *
 from PySide.QtGui import *
 
 # Some global variables
-OpenmsxGuiVersion = "0.0.1-1"
+OpenmsxGuiVersion = "0.0.1-2"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -27,6 +27,7 @@ P1button2key = ""
 Pausekey = ""
 Resetkey = ""
 Quitkey = ""
+gameName = ""
 
 def parse_config(self, filename):
         options = {}
@@ -109,6 +110,7 @@ class Ui_MainWindow(QMainWindow):
         QMainWindow.__init__(self, None)
         self.setWindowTitle("OpenMSX-gui")
         self.setAttribute(Qt.WA_Maemo5StackedWindow)
+	global RomPathActive
 	'''
 	Check for required files
 	'''
@@ -133,48 +135,10 @@ class Ui_MainWindow(QMainWindow):
 	backgroundLabel.setAlignment(Qt.AlignCenter | Qt.AlignLeft)
       	self.setCentralWidget(backgroundLabel)
 	# Get Gametitles from rom_path
-	if self.gui_opts["rom_path_active"] == "1":
-		ListCmd = "cd '" + self.gui_opts["rom_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null|sort -f" 
-	else:
-		if not os.path.isdir(self.gui_opts["rom2_path"]):
-			QMessageBox.critical(self, "Critical",  "rom2_path" + " '" + self.gui_opts["rom2_path"] + "' not found!")
-       			widget = pathWindow(self)
-			widget.show()
-		ListCmd = "cd '" + self.gui_opts["rom2_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null|sort -f" 
-	fin,fout = os.popen4(ListCmd)
-	romList = fout.read()
-	fin.close()
-	romList = romList.split('\n')
-	romList = romList[:-1]
-	if not romList:
-		romList = ['No roms found']
 
-        self.combo = QComboBox(self)
-        self.combo.setStyleSheet( \
-	"QComboBox { color: gray; \
-	 border: 6px solid #045FB4; \
-	 border-radius: 3px; \
-	 min-width: 6em; \
-	 }" )
-	self.combo.setGeometry(QRect(20, 50, 750, 60))
-	# Read last started file
-	try:
-		playedFile = open(LastPlayed_File,"r")
-	except:
-		last_game = "dummy"
-	else:
-		last_game = playedFile.readlines()
-	maxLength=63
-	for Game in romList:
-		space=""
-		spacecount=maxLength-len(Game)
-		for x in range(0,spacecount):
-			space=space+" "
-       		self.combo.addItem(space+Game)
-	self.GameFile=[[t] for t in romList if t]
-	# Set last file as current
-	if last_game[0] in romList:
-		self.combo.setCurrentIndex(romList.index(last_game[0]))
+        self.gameListButton = QPushButton(self)
+        self.gameListButton.setGeometry(QRect(20, 50, 750, 60))
+        self.connect(self.gameListButton, SIGNAL("clicked()"), self.pickGame)
 
 	# Define menubar
 	aboutAction = QAction( '&About', self)
@@ -183,16 +147,29 @@ class Ui_MainWindow(QMainWindow):
         configAction.triggered.connect(self.slotConfig)
 	self.romPath1Action = QAction( '&Use RomPath1', self)
 	self.romPath1Action.setCheckable(True)
-        self.romPath1Action.triggered.connect(self.slotRomPath1)
+        self.romPath1Action.triggered.connect(self.setGame1)
 	self.romPath2Action = QAction( '&Use RomPath2', self)
 	self.romPath2Action.setCheckable(True)
-        self.romPath2Action.triggered.connect(self.slotRomPath2)
+	self.romPath2Action.triggered.connect(self.setGame2)
 	if self.gui_opts["rom_path_active"] == "1":
 		self.romPath1Action.setChecked(True)
 	else:
 		self.romPath2Action.setChecked(True)
-		
 
+        # Read last started file
+        try:
+                playedFile = open(LastPlayed_File,"r")
+        except:
+                last_game = "Select game"
+        else:
+                last_game = playedFile.readlines()
+                if RomPathActive == "1":
+                        if os.path.isfile(self.gui_opts["rom_path"]+'/'+os.path.basename(''.join(last_game))):
+                                gameName = last_game
+                        else:
+                                last_game = "Select game"
+        self.gameListButton.setText(''.join(last_game))
+		
         menubar = self.menuBar()
         fileMenu = menubar.addMenu('&MainMenu')
         fileMenu.addAction(configAction)
@@ -214,45 +191,69 @@ class Ui_MainWindow(QMainWindow):
         self.onesmutePushButton.setGeometry(QRect(400, 370, 400, 55))
         self.onesmutePushButton.setFont(font)
 
+    def setGame1(self):
+        global RomPathActive
+        global gameName
+        self.romPath1Action.setChecked(True)
+        self.romPath2Action.setChecked(False)
+        gameName = ""
+        self.gameListButton.setText("Select game")
+        RomPathActive = "1"
+
+    def setGame2(self):
+        global RomPathActive
+        global gameName
+        if self.gui_opts["rom2_path"] not in "notset":
+                self.romPath1Action.setChecked(False)
+                self.romPath2Action.setChecked(True)
+                gameName = ""
+                self.gameListButton.setText("Select game")
+                RomPathActive = "2"
+        else:
+                self.romPath2Action.setChecked(False)
+
+    def pickGame(self):
+        gamePick = GamePickDialog(self)
+        gamePick.show()
+        if gameName:
+                self.gameListButton.setText(gameName)
 
     def on_start_clicked(self):
-	gameNbr = self.combo.currentIndex()
-	self.gameFile = str(self.GameFile[gameNbr]).strip("['']")
-
 	# Add all the options
 	# but first, re-read all settings
         self.gui_opts = parse_config(self,OpenmsxGui_CfgFile)
 	if self.gui_opts["machine"] == "C-Bios":
-		ALL_OPTS="-ext scc "
+		ALL_OPTS=" "
 	else:
 		# Panasonic machine chosen
 		for SystemRom in "fs-a1gt_firmware.rom", "fs-a1gt_kanjifont.rom":
 			if not (os.path.exists(Home + "/.openMSX/share/systemroms/" + SystemRom)):
 				if not (os.path.exists("/opt/openmsx/share/systemroms/" + SystemRom)):
 					QMessageBox.critical(self, "Critical",  SystemRom + " not found in /opt/openmsx/share/systemroms/ or " + Home + "/.openMSX/share/systemroms/")
-					ALL_OPTS="-ext scc "
+					ALL_OPTS=" "
 				else:	
-					ALL_OPTS="-machine " + self.gui_opts["machine"] + " -ext scc "
+					ALL_OPTS="-machine " + self.gui_opts["machine"] + " "
         if self.onesmutePushButton.isChecked():
 		ALL_OPTS= ALL_OPTS + "-script " + MuteOn_File + " "
         else:  ALL_OPTS= ALL_OPTS + "-script " + MuteOff_File + " "
 
-	if not (self.gameFile == "No roms found" ):
+	if not (gameName == "No roms found" or not gameName):
 		# Write as last played game
 		playedFile = open(LastPlayed_File,"w")
-		playedFile.write(self.gameFile)
+		playedFile.write(gameName)
 		playedFile.close()
-		file_extension = os.path.splitext(self.gameFile)[1][1:].upper()
+		file_extension = os.path.splitext(gameName)[1][1:].upper()
 		if self.gui_opts["machine"] == "C-Bios" and file_extension in ("DSK","XSA"):
 			QMessageBox.critical(self, "Critical", "Disk images are not supported with C-Bios activated")
-		# Start emulator with parameters
-		print self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile +  '"'
-		if RomPathActive != "":
-			self.gui_opts["rom_path_active"] = RomPathActive
-		if self.gui_opts["rom_path_active"] == "1":
-			QProcess.startDetached(self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + self.gameFile + '"' )
+		# Start emulator with parametersA
+                if RomPathActive != "":
+                        self.gui_opts["rom_path_active"] = RomPathActive
+		if RomPathActive == "1":
+			print self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + gameName +  '"'
+			QProcess.startDetached(self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom_path"] + "/" + gameName + '"' )
 		else:
-			QProcess.startDetached(self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom2_path"] + "/" + self.gameFile + '"' )
+			print self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom2_path"] + "/" + gameName +  '"'
+			QProcess.startDetached(self.gui_opts["exec_path"] + "/openmsx "+ALL_OPTS+ " " + '"' + self.gui_opts["rom2_path"] + "/" + gameName + '"' )
 
 		if (self.gui_opts["exit_after_launch"] == "true"):
 			time.sleep(5)
@@ -266,83 +267,54 @@ class Ui_MainWindow(QMainWindow):
         a = ConfigWindow(self)
         a.show()
 
-    def slotRomPath1(self):
-	# Load config
-	global RomPathActive
-        self.gui_opts = parse_config(self,OpenmsxGui_CfgFile)
-        if self.romPath1Action.isChecked():
-		self.romPath2Action.setChecked(False)
-		self.combo.clear()
-		RomPathActive = "1"
-		ListCmd = "cd '" + self.gui_opts["rom_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null|sort -f" 
-		fin,fout = os.popen4(ListCmd)
-		romList = fout.read()
-		fin.close()
-		romList = romList.split('\n')
-		romList = romList[:-1]
-		if not romList:
-			romList = ['No roms found']
-		# Read last started file
-		try:
-			playedFile = open(LastPlayed_File,"r")
-		except:
-			last_game = "dummy"
-		else:
-			last_game = playedFile.readlines()
-		maxLength=63
-		for Game in romList:
-			space=""
-			spacecount=maxLength-len(Game)
-			for x in range(0,spacecount):
-				space=space+" "
-       			self.combo.addItem(space+Game)
-		self.GameFile=[[t] for t in romList if t]
-		# Set last file as current
-		if last_game[0] in romList:
-			self.combo.setCurrentIndex(romList.index(last_game[0]))
-        else:
-		self.romPath2Action.setChecked(True)
+class GamePickDialog(QWidget):
+    def __init__(self,parent):
+        super(GamePickDialog, self).__init__(parent)
+        global RomPathActive
+        self.d = QDialog(self)
+        self.d.setMinimumHeight(380)
+        self.d.setMaximumHeight(380)
+        self.d.setWindowTitle("[Select game]")
+        hbox = QGridLayout()
+        horizontalLayout = QGridLayout()
+        self.gameWidget = QListWidget()
 
-    def slotRomPath2(self):
-	global RomPathActive
-	# Load config
+        # Load config
         self.gui_opts = parse_config(self,OpenmsxGui_CfgFile)
-        if self.romPath2Action.isChecked():
-		self.romPath1Action.setChecked(False)
-		self.combo.clear()
-		RomPathActive = "2"
-		if not os.path.isdir(self.gui_opts["rom2_path"]):
-			QMessageBox.critical(self, "Critical",  "rom2_path" + " '" + self.gui_opts["rom2_path"] + "' not found!")
-       			widget = pathWindow(self)
-			widget.show()
-		ListCmd = "cd '" + self.gui_opts["rom2_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null  2>/dev/null|sort -f" 
-		fin,fout = os.popen4(ListCmd)
-		romList = fout.read()
-		fin.close()
-		romList = romList.split('\n')
-		romList = romList[:-1]
-		if not romList:
-			romList = ['No roms found']
-		# Read last started file
-		try:
-			playedFile = open(LastPlayed_File,"r")
-		except:
-			last_game = "dummy"
-		else:
-			last_game = playedFile.readlines()
-		maxLength=63
-		for Game in romList:
-			space=""
-			spacecount=maxLength-len(Game)
-			for x in range(0,spacecount):
-				space=space+" "
-       			self.combo.addItem(space+Game)
-		self.GameFile=[[t] for t in romList if t]
-		# Set last file as current
-		if last_game[0] in romList:
-			self.combo.setCurrentIndex(romList.index(last_game[0]))
+        if RomPathActive == "1":
+		ListCmd = "cd '" + self.gui_opts["rom_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null|sort -f" 
         else:
-		self.romPath1Action.setChecked(True)
+		ListCmd = "cd '" + self.gui_opts["rom2_path"] + "' 2>/dev/null && ls -1 *.zip *.ZIP *.rom *.ROM *.dsk *.DSK *.cas *.CAS *.wav *.WAV *.xsa *.XSA 2>/dev/null|sort -f" 
+        fin,fout = os.popen4(ListCmd)
+        romList = fout.read()
+        fin.close()
+        romList = romList.split('\n')
+        romList = romList[:-1]
+        if not romList:
+                romList = ['No roms found']
+
+        for Game in romList:
+                item = QListWidgetItem(Game)
+                item.setTextAlignment(Qt.AlignCenter)
+                self.gameWidget.addItem(item)
+                if Game == gameName:
+                        currItem = item
+
+        # Set most recent file as current
+        if gameName in romList:
+                self.gameWidget.setCurrentItem(currItem)
+
+        horizontalLayout.addWidget(self.gameWidget,0,0)
+        self.d.setLayout(hbox)
+        hbox.addLayout (horizontalLayout,0,0)
+
+        self.connect(self.gameWidget, SIGNAL("itemClicked(QListWidgetItem *)"), self.itemClicked)
+        self.d.exec_()
+
+    def itemClicked(self, item):
+        global gameName
+        gameName = item.text()
+        self.d.close()
 
     def slotJoyconf(self):
         a = JoyconfWindow(self)
@@ -373,10 +345,10 @@ class AboutWindow(QMainWindow):
                    "<p>OpenMSX-gui is written in PySide by <i>Arno Dekker</i> 2012<p><br>" \
                    "<u>Used special key mappings:</u>" \
                    "<ul align=left>" \
-                   "<li> N900 MODE+BACKSPACE mapped to MSX DELETE" \
-                   "<li> N900 MODE+ENTER mapped to MSX INSERT" \
-                   "<li> N900 CTRL+Q,W,E,R,T mapped to MSX F1,F2,F3,F4,F5" \
-                   "<li> N900 CTRL+X to toggle console" \
+                   "<li> - N900 MODE+BACKSPACE mapped to MSX DELETE" \
+                   "<li> - N900 MODE+ENTER mapped to MSX INSERT" \
+                   "<li> - N900 CTRL+Q,W,E,R,T mapped to MSX F1,F2,F3,F4,F5" \
+                   "<li> - N900 CTRL+X to toggle console" \
                    "</ul>" \
                    "<br>" \
                    '<FONT FACE= "Courier New"><a href="http://openmsx.sourceforge.net/">Visit openMSX homepage</a><br>' \
